#
# spec file for package syncthing-gtk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __requires_exclude typelib\\((Caja|Nautilus|Nemo)\\)
%define _name   syncthing_gtk
Name:           syncthing-gtk
Version:        0.9.3.1
Release:        bp153.1.17
Summary:        Syncthing Gtk-based graphical interface
License:        GPL-2.0-or-later
Group:          Productivity/Networking/File-Sharing
Url:            https://github.com/syncthing/syncthing-gtk
Source:         https://github.com/syncthing/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM syncthing-gtk-fix-config-read.patch sor.alexei@meowr.ru -- Fix configuration read with non-ASCII locales.
Patch0:         syncthing-gtk-fix-config-read.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  syncthing >= 0.13
BuildRequires:  update-desktop-files
Requires:       psmisc
Requires:       syncthing >= 0.13
Recommends:     %{name}-lang
Recommends:     libnotify
Recommends:     librsvg
# caja-extension-syncthing-gtk was last used in openSUSE Leap 42.1.
Provides:       caja-extension-%{name} = %{version}
Obsoletes:      caja-extension-%{name} < %{version}
# nautilus-extension-syncthing-gtk was last used in openSUSE Leap 42.1.
Provides:       nautilus-extension-%{name} = %{version}
Obsoletes:      nautilus-extension-%{name} < %{version}
# nemo-extension-syncthing-gtk was last used in openSUSE Leap 42.1.
Provides:       nemo-extension-%{name} = %{version}
Obsoletes:      nemo-extension-%{name} < %{version}
BuildArch:      noarch
%if 0%{?suse_version} >= 1500
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
Requires:       python2-bcrypt
Requires:       python2-gobject
Requires:       python2-gobject-Gdk
Requires:       python2-gobject-cairo
Requires:       python2-python-dateutil
Recommends:     python2-pyinotify
%else
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python-bcrypt
Requires:       python-dateutil
Requires:       python-gobject
Requires:       python-gobject-Gdk
Requires:       python-gobject-cairo
Recommends:     python-pyinotify
%endif

%description
Graphical user interface with notification area icon for Syncthing
based on GTK+ and Python.

Supported Syncthing features:
 * Everything what WebUI can display.
 * Adding / editing / deleting nodes.
 * Adding / editing / deleting repositories.
 * Restart / shutdown server.
 * Editing daemon settings.

Additional features:
 * First run wizard for initial configuration.
 * Running Syncthing daemon in background.
 * Half-automatic setup for new nodes and repositories.
 * Filesystem watching and instant synchronisation using inotify.
 * Caja, Nemo, and Nautilus file managers integration.
 * Desktop notifications.

%lang_package

%prep
%setup -q
%patch0 -p1
sed -i 's/^\(Exec=\).*$/\1%{name}/' %{name}.desktop

%build
python2 setup.py build_py \
  --nostdownloader

%install
python2 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

%suse_update_desktop_file -r %{name} Network FileTransfer
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license LICENSE
%else
%doc LICENSE
%endif
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{python_sitelib}/%{_name}/
%{python_sitelib}/%{_name}-*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*.png
%{_datadir}/icons/hicolor/*/emblems/emblem-*.png
%{_datadir}/icons/hicolor/*/status/si-*.png
%{_datadir}/pixmaps/*.png
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sat Mar 17 2018 sor.alexei@meowr.ru
- Update to version 0.9.3.1:
  * Fix a connection error when HTTPS is enabled.
  * Fix connection issues when a directory has space in ID.
  * Add a fallback for loading QR code when http gvfs backend is
    not available.
  * Fix an icon in the about dialogue not showing.
  * Update translations.
* Fri Feb 23 2018 sor.alexei@meowr.ru
- Update to version 0.9.3:
  * Should fix problems with random crashes, out-of-date directory
    states and UI breaking after laptop is resumed from sleep.
  * Add a link to the "file downloaded" notification.
  * Add UI Settings to the status icon menu.
  * Add support for AppImage.
  * Fix Nautilus integration not working with latest Nautilus
    versions.
  * Fix status icon being invisible.
  * Fix symlinks not counted files.
- Rebase syncthing-gtk-fix-config-read.patch.
* Fri Oct 27 2017 sor.alexei@meowr.ru
- Update to version 0.9.2.7 (changes since 0.9.2.5):
  * Fix not being able to set dynamic and non-dynamic device
    addresses at one.
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 0.9.2.5:
  * Change wording in notification for better clarity.
  * Add a config-only option to disable status icon animation.
  * Add a -o argument, dumps captured Syncthing daemon output to
    stdout.
  * Add an argument to disable the status icon.
  * Fix filesystem watching failing on directories with space in
    id.
  * 1st run wizard now stores the password hash directly instead of
    leaving hashing to Syncthing.
  * Switch to timeout_add_seconds for inotify polling.
  * Add a Polish translation.
* Mon Feb  6 2017 sor.alexei@meowr.ru
- Update to version 0.9.2.4:
  * Fix some typos.
  * Update translations.
- Remove the hack to change execution bits: not really needed.
* Tue Dec 27 2016 sor.alexei@meowr.ru
- Add syncthing-gtk-fix-config-read.patch: Fix configuration read
  with non-ASCII locales.
* Mon Nov 28 2016 sor.alexei@meowr.ru
- Update to version 0.9.2.3:
  * Fix Portuguese language missing in language settings.
* Sat Sep 10 2016 sor.alexei@meowr.ru
- Update to version 0.9.2.2:
  * Support for directory labels in notifications.
  * Not sending 'Host' header breaks Syncthing 0.14.6 or newer.
  * Add Brazilian Portuguese translation.
* Tue Aug 30 2016 sor.alexei@meowr.ru
- Update to version 0.9.2.1 (changes since 0.9.1):
  * Add black and white icons theme, selectable in UI settings.
  * New directory ID is pre-filled with auto-generated ID.
  * Add a man page.
  * Add Spanish translation.
  * Fix error message about incompatible nodes being repeated
    infinitely.
  * Fix File Pull Order defaulting to nothing.
  * Fix "Override remote changes" option not doing anything.
  * 'tcp://' is prepended to dynamic address in directory editor.
  * Add more error details when '404/Not Found' error is generated.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.9.1:
  * Now compatible with Syncthing v0.14.x.
  * Display notification when .sync-conflict file is created.
  * Handle error message about outdated syncthing on remote device.
  * Rename Chinese localisation directory.
* Sat Jun 25 2016 sor.alexei@meowr.ru
- Update to version 0.9.0.3:
  * Better cookie handling when no username nor API key is set.
  * Update about dialog with link to author's Patreon page.
* Thu May 26 2016 sor.alexei@meowr.ru
- Update to version 0.9.0.2:
  * Fix UI Settings crashes on small screen.
  * Fix Daemon Settings crash.
* Tue May 17 2016 sor.alexei@meowr.ru
- Update to version 0.9.0.1 (changes since 0.8.3):
  * Syncthing 0.13 and above API.
  * Add support for directory labels.
  * Add support for Identification of Connections from
    Unknown Devices.
  * Add label that notifies user when changed setting needs
    syncthing-gtk restart.
  * Add 'File Pull Order' and 'Minimum Free Disk Space' fields to
    directory editor.
  * Change formatting in speed limit fields.
  * Fix updater extracting systemd units.
  * Add Chinese, Russian and Lithuanian localisations.
* Sun May  8 2016 badshah400@gmail.com
- Add Requires: python-gobject-Gdk, since this was split out of
  python-gobject into its own sub-package and should now be
  required by all GUI applications.
* Sun Apr 17 2016 sor.alexei@meowr.ru
- Remove {caja,nemo,nautilus}-extension-syncthing-gtk:
  syncthing-gtk handles that by itself (boo#975873).
* Fri Mar 25 2016 sor.alexei@meowr.ru
- Update to 0.8.3 (boo#976937):
  * Add "Advanced" tab into UI Settings with options to change
    Syncthing daemon arguments and environment variables.
  * Fix handling Syncthing restarting.
  * Fix repository with space in ID not refreshing correctly.
* Fri Jan 22 2016 sor.alexei@meowr.ru
- Update to 0.8.2:
  * Fix about window not showing in some languages.
  * Support timestamps with GTM+0 or without timezone.
  * And two random, mostly harmless error messages.
* Mon Dec 14 2015 sor.alexei@meowr.ru
- Update to 0.8.1 (changes since 0.8):
  * Fix Syncthing version of remote node not shown.
  * Missing definition causing UI problems and Appreport madness
    on Ubuntu.
  * Update syncthing-inotify version to 0.6.7.
  * Add support for download placeholders in Nautilus plugin.
  * Add localisation support with translations for Czech, German,
    and Slovak languages.
- Add syncthing-gtk-lang package.
- Create {caja,nemo,nautilus}-extension-syncthing-gtk packages with
  Caja, Nemo, and Nautilus plugins.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 0.8:
  * Syncthing 0.12 and above API.
  * No 'ignore' button on Unknown device message.
* Mon Oct 12 2015 sor.alexei@meowr.ru
- Update to 0.7.6.1:
  * Fix missing image definition causes crash with some GLib
    versions.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Update to 0.7.6:
  * Fix crash on too old and too recent glib.
  * Fix inotify (filesystem watcher) not being aware of created
    directories.
  * Fix Caja / Nautilus plugin ignoring some files until view is
    refreshed.
* Wed Sep  2 2015 sor.alexei@meowr.ru
- Update to 0.7.5.1 (changes since 0.7.4.1):
  * Better support for dark GTK+ themes.
  * Fix showing stopped folders as "up-to-date".
  * Fix notification icon missing on i3wm.
* Tue Jul 28 2015 sor.alexei@meowr.ru
- Update to 0.7.4.1:
  * Add scrollbars around directory list and device list, fixing
    display on small screens.
  * Fix starting syncthing-gtk.py from a directory with unicode
    characters in path.
  * Move filemanager emblems to where specification expects them.
  * Fix invalid links and typos.
* Tue Jun 30 2015 sor.alexei@meowr.ru
- Update to 0.7.4:
  * Add displaying "(watch)" next to directory's rescan interval if
    filesystem watching is enabled.
  * Add support for extenal and trashcan versioning.
  * Add --nostdownloader argument to setup.py, for disabling
    Syncthing updater on "compile" time.
  * Fix compatibility with non-GNU nice command.
  * Fix filesystem watcher not reporting files with space in path.
- Disable Syncthing updater.
* Thu Jun 11 2015 sor.alexei@meowr.ru
- Update to 0.7.3:
  * Fix IPv6 address cut out in 'Add new device' dialog.
  * Fix broken filesystem watcher.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 0.7.2 (changes since 0.7.1.1):
  * Fix first run wizard crashing because of missing icon.
  * Add support for Exherbo's filesystem layout.
  * Add support for small screens.
* Tue May 19 2015 sor.alexei@meowr.ru
- Initial package.
